package com.agri.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.agri.system.domain.SysAgriLimit;

/**
 * 执行时间限位管理Mapper接口
 * 
 * @author agri
 * @date 2026-01-08
 */
public interface SysAgriLimitMapper extends BaseMapper<SysAgriLimit>
{
    /**
     * 查询执行时间限位管理
     * 
     * @param id 执行时间限位管理主键
     * @return 执行时间限位管理
     */
    public SysAgriLimit selectSysAgriLimitById(String id);

    /**
     * 查询执行时间限位管理列表
     * 
     * @param sysAgriLimit 执行时间限位管理
     * @return 执行时间限位管理集合
     */
    public List<SysAgriLimit> selectSysAgriLimitList(SysAgriLimit sysAgriLimit);

    /**
     * 新增执行时间限位管理
     * 
     * @param sysAgriLimit 执行时间限位管理
     * @return 结果
     */
    public int insertSysAgriLimit(SysAgriLimit sysAgriLimit);

    /**
     * 修改执行时间限位管理
     * 
     * @param sysAgriLimit 执行时间限位管理
     * @return 结果
     */
    public int updateSysAgriLimit(SysAgriLimit sysAgriLimit);

    /**
     * 删除执行时间限位管理
     * 
     * @param id 执行时间限位管理主键
     * @return 结果
     */
    public int deleteSysAgriLimitById(String id);

    /**
     * 批量删除执行时间限位管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysAgriLimitByIds(String[] ids);
}
